setToken method
Sets the token and updates the expiry date based on the configured session duration.
Implementation
void setToken(String token) {
_tokenManager.setToken(token);
}
Sets the token and updates the expiry date based on the configured session duration.
void setToken(String token) {
_tokenManager.setToken(token);
}