DataSystemRepository class
Constructors
- DataSystemRepository({required VendureRemoteDataSource dataSource})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAvailableCountries(
) → Future< List< Country> > -
getFacet(
{required String id}) → Future< Facet> -
getFacets(
{FacetListOptions? options}) → Future< FacetList> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited