PaymentMethodQuote class

Annotations
  • @freezed

Constructors

PaymentMethodQuote({required String code, Map<String, dynamic>? customFields, required String description, String? eligibilityMessage, required String id, required bool isEligible, required String name})
const
factory
PaymentMethodQuote.fromJson(Map<String, dynamic> json)
factory

Properties

code String
no setterinherited
copyWith → $PaymentMethodQuoteCopyWith<PaymentMethodQuote>
no setterinherited
customFields Map<String, dynamic>?
no setterinherited
description String
no setterinherited
eligibilityMessage String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
isEligible bool
no setterinherited
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited