PromotionList class

Annotations
  • @freezed

Constructors

PromotionList({required List<Promotion> items, required int totalItems})
const
factory
PromotionList.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PromotionListCopyWith<PromotionList>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
items List<Promotion>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalItems int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited