StringCustomFieldConfig class

Annotations
  • @freezed

Constructors

StringCustomFieldConfig({List<LocalizedString>? description, bool? internal, List<LocalizedString>? label, int? length, required bool list, required String name, bool? nullable, List<StringFieldOption>? options, String? pattern, bool? readonly, List<Permission>? requiresPermission, required String type, Map<String, dynamic>? ui})
const
factory
StringCustomFieldConfig.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $StringCustomFieldConfigCopyWith<StringCustomFieldConfig>
no setterinherited
description List<LocalizedString>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internal bool?
no setterinherited
label List<LocalizedString>?
no setterinherited
length int?
no setterinherited
list bool
no setterinherited
name String
no setterinherited
nullable bool?
no setterinherited
options List<StringFieldOption>?
no setterinherited
pattern String?
no setterinherited
readonly bool?
no setterinherited
requiresPermission List<Permission>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setterinherited
ui Map<String, dynamic>?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited